pub const fn translate_mouse_button(button: MouseButton) -> Option<MouseButton>Expand description
Translates a winit [winit::event::MouseButton] into our MouseButton.
Returns None for side buttons and other unrecognized buttons.
pub const fn translate_mouse_button(button: MouseButton) -> Option<MouseButton>Translates a winit [winit::event::MouseButton] into our MouseButton.
Returns None for side buttons and other unrecognized buttons.